<?php

namespace Litecms\Notice\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Notice\Models\Notice;

class NoticePolicy
{

    /**
     * Determine if the given user can view the notice.
     *
     * @param UserPolicy $user
     * @param Notice $notice
     *
     * @return bool
     */
    public function view(UserPolicy $user, Notice $notice)
    {
        if ($user->canDo('notice.notice.view') && $user->isAdmin()) {
            return true;
        }

        return $notice->user_id == user_id() && $notice->user_type == user_type();
    }

    /**
     * Determine if the given user can create a notice.
     *
     * @param UserPolicy $user
     * @param Notice $notice
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('notice.notice.create');
    }

    /**
     * Determine if the given user can update the given notice.
     *
     * @param UserPolicy $user
     * @param Notice $notice
     *
     * @return bool
     */
    public function update(UserPolicy $user, Notice $notice)
    {
        if ($user->canDo('notice.notice.edit') && $user->isAdmin()) {
            return true;
        }

        return $notice->user_id == user_id() && $notice->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given notice.
     *
     * @param UserPolicy $user
     * @param Notice $notice
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Notice $notice)
    {
        return $notice->user_id == user_id() && $notice->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given notice.
     *
     * @param UserPolicy $user
     * @param Notice $notice
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Notice $notice)
    {
        if ($user->canDo('notice.notice.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given notice.
     *
     * @param UserPolicy $user
     * @param Notice $notice
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Notice $notice)
    {
        if ($user->canDo('notice.notice.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
